@@ -192,7 +192,7 @@ sub _set_parent {
 sub __any_path {
     my $self = shift;
     my $sess = shift;
-    my ( $method, @path ) = @_;
+    my ( $method ) = @_;
     my ( $res, @path ) = $self->SUPER::__any_path( $sess, @_ );
     return undef unless defined($res);
     if ( ref($res) eq 'ARRAY' ) {
@@ -210,7 +210,6 @@ sub __any_path {
 sub _traverse_ {
     my $self = shift;
     my $sess = shift;
-
     #if empty path return $self
     unless ( scalar(@_) ) { return ( $self, $self ) }
 
@@ -290,6 +289,8 @@ sub _traverse_ {
 #deprecated
 sub _call_method {
     my $self = shift;
+        _deprecated $self "_traverse_";
+
     my ( $name, @path ) = @{ shift @_ };
     return $self->SUPER::_call_method( [ $name, @path ], @_ ) || do {
         if ( my $obj = $self->_get_obj_by_name($name) ) {
@@ -348,132 +349,6 @@ sub _destroy {
     $self->SUPER::_destroy;
 }
 
-=head2 _get_object_by_path <$path>, [$session]
-
-Return first Element object for path.
-Try to load objects for current object.
-
-=cut
-
-#deprecated
-sub _get_object_by_path {
-    my $self    = shift;
-    my $path    = shift;
-    my $session = shift;
-
-    #    _log1 $self Dumper {'$self'=>ref($self), path=>$path};
-    my @backup_path = @$path;
-    my $next_name   = $path->[0];
-
-    #first try get by name
-    if ( my $obj = $self->_get_obj_by_name($next_name) ) {
-        shift @$path;    #skip first name
-                         #ok got it
-                         #check if it container
-                         #skip extra path
-        if ( UNIVERSAL::can( $obj, '__extra_path' ) ) {
-            my $extra_path = $obj->__extra_path;
-
-            #if extra path defined and not ref convert to ref
-            if ( defined $extra_path ) {
-                $extra_path = [$extra_path] unless ref($extra_path);
-            }
-            if ( ref($extra_path) ) {
-                my @extra = @$extra_path;
-
-                #now skip extra
-                for (@extra) {
-                    if ( $path->[0] eq $_ ) {
-                        shift @$path;
-                    }
-                    else {
-                        _log2 $self "Break __extra_path "
-                          . $path->[0] . " <> "
-                          . $_
-                          . " for : $obj";
-                        last;
-                    }
-                }
-            }
-        }
-        if ( $obj->isa('WebDAO::Container') ) {
-            return $obj unless @$path;    # return object if end of path
-            return $obj->_get_object_by_path( $path, $session );
-        }
-        else {
-
-            #if element return point in any way
-            return $obj;
-        }
-    }
-    else {
-
-        #try get objects by special methods
-        my $dyn = $self->__get_objects_by_path( $path, $session )
-          || return;    #break search
-
-        #handle self controlled objects
-        if ( $dyn eq $self ) {
-            return $self;
-        }
-        $dyn = [$dyn] unless ref($dyn) eq 'ARRAY';
-
-        #now try find object in returned array
-        my $next;
-        foreach (@$dyn) {
-
-            #skip non objects
-            next unless $_->_obj_name eq $next_name;
-            $next = $_;
-            last;    #exit from loop loop
-        }
-        unless ($next) {
-            return    # return undef unless find objects
-        }
-        else {
-
-            # yes, from returned object present traverse continue
-            #if defined $session ( load scene)
-            if ($session) {
-                $self->_add_childs(@$dyn);
-                return $self->_get_object_by_path( $path, $session );
-            }
-            else {
-
-                #if query without session
-                #try to find  by name
-                #ok got it
-                #check if it container
-                if ( $next->isa('WebDAO::Container') ) {
-                    return $next->_get_object_by_path( $path, $session );
-                }
-                else {
-
-                    #return object referense in any way
-                    return $next;
-                }
-            }
-
-        }
-    }
-}
-
-=head2 __get_objects_by_path [path], $session
-
-Return next object for path 
-
-=cut
-
-#deprecateed
-sub __get_objects_by_path {
-    my $self = shift;
-    my ( $path, $session ) = @_;
-
-    # check if path point to method
-    return $self if $self->can( $path->[0] );
-    return;    # default return undef
-}
-
 1;
 __DATA__
 
